# Data

## Data sources
The data used in this project were obtained from the DA’s office of SCC, which stores its case information in a case management database called CIBERlaw. We recieved data for all felony cases charged by the SCC DA's office between January 1st and June 30th 2014 for adult defendants. The reason for this specific timeframe is twofold. Firstly, on the 5th of November 2014, Proposition 47 was passed in a referendum in California. With Proposition 47 certain non-violent drug and property crimes in the state were reclassified as misdemeanors instead of felonies. It was at the request of SCC DA's office that the time period selected would be one prior to these changes. Secondly, to maximise the proportion of cases concluded at the time of research it is preferrable to examine a not too recent time period. The data arrived as four separate datasets:

* __Case Information__: Case Information has the base information of each case: case ID numbers, defendant ID numbers, the time a case is logged, and other basic information for each case. It also has demographic information for each defendant: race/ethnicity, gender, age and zipcode of residence. The dataset contains 4,794 observations, with the same number of unique defendant ID's and 4,405 unique case ID's.
* **Defendant Charges**: Defendant charges has information on the charges facing defendants relayed in penal codes. It contains 34,421 observations with 15,668 unique case IDs.
* **Charge Enhancements**: Charge enhancements has limited information on prior convictions of defendants as well as enhancements on current charges. When a charge (from Defendant Charges dataset) is enhanced it mandates harsher sentancing. An examle of this is if a driver is charged for driving under the influence of alcohol. Should the alcohol level of his blood be above a certain threshold, or the driver refuses to have his blood tested for alcohol levels, the original charge for driving under the influence is enhanced. The dataset contains 10,831 observations with 3,640 unique case IDs
* **Case Events**: Case events has information on all court events that are related to a case. Each event is timestamped, and falls into one of 155 distinct case event types and one of 469 distict case event results. To construct a simplified timeline of a case, four key events must be recognized and extracted: arraignment, plea, case disposition, and a case last event. In some cases the event is explicitly stated in the categories, in others it must be inferred. Identifying these key events is key to merging the data and gaining insights about prosecution durations. The dataset contains 481,614 observations with 14,983 unique case IDs.

To protect the privacy of defendants both defendant and case ID's are anonymized from their entries in SCC's database. These ID's are then used to merge the four datasets into a single set containing all the relevant information on each case. When merging the Case Information dataset with Defendant Charges 6 observations are lost, taking the total number of observations form 4,794 to 4,788. Merging Charge Enhancements with the resulting dataset from the previous merge has no affect on the number of observations (as only some cases will carry enhancements the merge is based solely on case ID's and defendant ID's found in the already merged dataset - 'left' merge). Merging Case Events with the outcome of previous merges 278 observations are lost, taking the number of observations from 4,794 to 4,510.

Misdemeanor data were included in the Defendant Charges and Case Events tables which explains why we find much higher numbers of case ID's in those sets of data than in Case Information. All of the misdemeanors get discarded in the merge process. The reason we lose observations in the merging process stems from the fact that some case and defendant ID pairs found in Case Information are missing in Defendant Charges and Case Events. Without direct access to the CIBERlaw system, we cannot know the causes of these discrepancies.

## Construction of timelines
To understand what causes delays in the prosecutorial process, one must first understand the timeline of a case. From the point of view of a prosecutor, a case generally ends at disposition, or resolution. A disposition usually takes the form of either a dismissal, guilty verdict, acquittal, or guilty plea. In the CIBERlaw system, there is no single event that explicitly logs the disposition of a case. Instead there is a number of case event type and results combinations that can represent disposition (the dictionaries that map event categories and subcategories to our event classification are available on the project gitlab repository). By going through the possible combinations, we identified the disposition event for 90% of our cases. The remaining 10% are missing clear disposition dates. This is most likely because the disposition event was logged in a separate database of Santa Clara County courts, or due to the fact that the case has not been concluded yet.

Time to disposition is defined as time from case issuing to the first event having one of the following results: *formal probation granted, credit time served, summary probation granted, sentenced, prison sentenced imposed, defendant deceased, found guilty, found not guilty, defendant released by court, defendant discharged, deferred entry of judgment PC1000, cases consolidated, charges suspended per civil compromise, motion to dismiss interest justice granted*, or *motion to dismiss case granted*.

We are also interested in looking at three other key events for each case: arraignment, plea and last event. The arraignment is identified as the first event for a case of type Arraignment. Plea is identified as the first case event result of one of ‘*Plead guilty*’, ‘*Plead not guilty*’, ‘*Not guilty plea entered by court*’ or ‘*Plead nolo contendere*’. A plea of _nolo contendere_, or no contest, is a plea where the defendant neither admits nor disputes charges. While it isn't technically a guilty plea it has the same immediate effect. Last event is the very last event logged to a case. 3% of cases have no identifiable arraignment event and 7% of cases have no identifiable plea event.

From these four different events for each case we construct the timelines. The timelines are calculated at the day precision starting from the day a case is issued; *days-to-arraignment*, *days-to-plea*, *days-to-disposition*, and *days-to-last-event*. Out of the 4,510 observations of the merged dataset we find that days-to-arraignment has a negative value for 76 observations, days-to-plea is negative for 69 observations, days-to-disposition is negative for 71 observation and days-to-last is negative for 29 observations. All in all we have 79 negative observations (three arraignments have missing values). These negatives result from the fact that the issuance of a case happens at a later date than might be expected. One specifica and at random example of this is a certain case where disposition happens in September of 2014 and the last event registered to the case is in December of 2015. However the case is issued in April of 2016 rendering all time values negative.

Some of these negative time-lines can be explained with cases being reopened after sentencing. For example, ten of those are due to Proposition 47. Some, though, cannot be easily explained. These 79 observations have been dropped from the dataset, taking observations from 5,510 to 4,431. The resulting timelines can be seen in Table \ref{tab:timelines}.

## Engineered Features
From the attributes of the original sets of data new features were engineered to retain all relevant information we are interested in examining and encode it in a format that enables visualization and modeling. The variables are encoded as either integers (e.g. number of charges for a defendant/case pair), binary (e.g. whether there was a preliminary hearing or not), categorical (e.g. pleas guilty, not guilty, _nolo contendere_), or continuous interval variables (e.g. defendant’s age). The features are: